#!/bin/sh
# Usage: sh get_twistcli.sh ./twistcli

CLI_FILE="${1}"
CLI_PATH_DIR=$(dirname "${CLI_FILE}")
# Remove URL scheme as that will be prepended later
TWIST_CLI_H=$(echo "${TWIST_CLI_H}" | sed "s|^https://||")

# This function obtains PrismaCloud JWT. Relies on env vars TWIST_CLI_H, TWIST_CLI_U, TWIST_CLI_P
get_token()
{
	curl \
		-s \
		-X POST \
		"https://${TWIST_CLI_H}/api/v1/authenticate" \
		-H "Content-Type: application/json;charset=UTF-8" \
		-d "{\"username\":\"${TWIST_CLI_U}\",\"password\":\"${TWIST_CLI_P}\"}" |\
			sed 's:{"token"\:"\(.*\)"}:\1:'
}

# Check if dir exists
if test ! -d "${CLI_PATH_DIR}"
then
	echo "Directory '${CLI_PATH_DIR}' does not exist!"
	exit 1
fi

# Check if CLI_FILE is a file or does not exit
if [ -e "${CLI_FILE}" ] && [ ! -f "${CLI_FILE}" ]
then
	echo "'${CLI_FILE}' exists and is not a file!"
	exit 2
fi


TOKEN=$(get_token)
if [ -z "${TOKEN}" ]
then
	echo "Something went wrong when obtaining token for: ${TWIST_CLI_H}"
	exit 3
fi

echo "Downloading twistcli..."
curl -s "https://${TWIST_CLI_H}/api/v1/util/twistcli" --header "authorization: Bearer ${TOKEN}" -o "${CLI_FILE}"
echo "Download completed!"

# Check if downloaded file is indeed executable
if ! file "${CLI_FILE}" | grep "executable" >/dev/null
then
	if which file 2>/dev/null
	then
		echo "Something went wrong! Could not download the twistcli executable!"
		exit 4
	else
		echo "'file' command not found. Can't verify downloaded file is an executable."
	fi
fi

chmod a+x "${CLI_FILE}"
"${CLI_FILE}" --version
