#!/bin/sh
# Usage: sh get_osspi.sh 1.2.3 beta

# This script downloads the OSSPI CLI and the OSSTP tool
# All versions of OSSPI can be found here:
# https://artifactory.eng.vmware.com/ui/native/osspicli-local/beta/osspicli/

OSSPI_VER=$1
BRANCH=$2
ARTIFACTORY_URL="https://build-artifactory.eng.vmware.com"
OSSTP_URL="https://osm.eng.vmware.com/utilities/osstpclients3.zip"

if [ -z "$BRANCH" ]; then
    BRANCH="beta"
fi

if [ -z "$OSSPI_VER" ]; then
    printf "** INFO: OSSPI CLI version not provided. Setting it to latest\n"

    BRANCH="beta"
    OSSPI_VER="$(curl --fail -s "$ARTIFACTORY_URL/api/search/latestVersion?g=$BRANCH&a=osspicli&repos=osspicli-local")"
fi

OSSPI_DOWNLOAD_URL="$ARTIFACTORY_URL/osspicli-local/$BRANCH/osspicli/osspicli-$OSSPI_VER.tar.gz"

printf "** INFO: Downloading OSSPI CLI version %s\n" "$OSSPI_VER"

curl "$OSSPI_DOWNLOAD_URL" -o osspi.tar.gz

printf "** INFO: OSSPI download complete!\n"

printf "** INFO: Downloading OSSTP\n"

curl "$OSSTP_URL" -o osstp.zip

printf "** INFO: OSSTP download complete!\n"